@@ -1,13 +1,11 @@
 """Module for common class between gRPC, Archive, and Result geometry"""
 import warnings
-from functools import wraps
 
 import pyvista as pv
 import vtk
 import numpy as np
 
 from pyansys import _relaxmidside, _reader
-from pyansys.misc import vtk_cell_info
 from pyansys.elements import ETYPE_MAP
 
 
@@ -32,8 +30,8 @@ MESH200_MAP = {0: 2,  # line
 
 class Geometry():
 
-    def __init__(self, nnum, nodes, elem, elem_off, ekey, node_comps={},
-                 elem_comps={}, rdat=[], rnum=[], keyopt={}):
+    def __init__(self, nnum, nodes, elem=None, elem_off=None, ekey=None,
+                 node_comps={}, elem_comps={}, rdat=[], rnum=[], keyopt={}):
         self._etype = None  # internal element type reference
         self._grid = None  # VTK grid
         self._enum = None  # cached element numbering
@@ -46,7 +44,7 @@ class Geometry():
         self._secnum = None  # cached section number
         self._esys = None  # cached element coordinate system
 
-        # must be set by subclass
+        # Set on init
         self._nnum = nnum
         self._nodes = nodes
         self._elem = elem
@@ -109,7 +107,7 @@ class Geometry():
                                                            self._elem_off,
                                                            type_ref,
                                                            self.nnum,
-                                                           not VTK9)
+                                                           True)  # for reset_midside
         nodes, angles, nnum = self.nodes, self.node_angles, self.nnum
 
         # fix missing midside
@@ -502,19 +500,15 @@ class Geometry():
         txt += '  Number of Element Components: %d\n' % len(self.element_components)
         return txt
 
-    @wraps(pv.plot)
-    def plot(self, *args, **kwargs):
-        """Plot the ANSYS grid"""
-        self.grid.plot(*args, **kwargs)
-
 
 def fix_missing_midside(cells, nodes, celltypes, offset, angles, nnum):
     """Adds missing midside nodes to cells.
 
     ANSYS sometimes does not add midside nodes, and this is denoted in
     the element array with a ``0``.  When translated to VTK, this is
-    saved as a ``-1``.  If this is not corrected, VTK will segfault,
-    and this function creates missing midside nodes for the quadratic
+    saved as a ``-1``.  If this is not corrected, VTK will segfault.
+
+    This function creates missing midside nodes for the quadratic
     elements.
     """
     # Check for missing midside nodes
